@@ -191,7 +191,6 @@ class _RMProject(_project._Project):
         if self._components and not force:
             return
         logger.info( f"load_components_and_configurations {self=} {self.is_optin=}" ) 
-        print( f"load_components_and_configurations {self=} {self.is_optin=} {self._components=} {self._configurations=}" ) 
         self._components = {}
         self._configurations = {}
         ncomps = 0
@@ -308,7 +307,6 @@ class _RMProject(_project._Project):
                     compu = component_el.get("{%s}resource" % rdfxml.RDF_DEFAULT_PREFIX["rdf"])
                     compx = self.execute_get_rdf_xml(compu, intent="Retrieve component definition to find all configurations", action="Retrieve each configuration")
                     comptitle = rdfxml.xmlrdf_get_resource_text(compx, './/dcterms:title')
-
                     confu = rdfxml.xmlrdf_get_resource_uri(compx, './/oslc_config:configurations')
                     self._components[compu] = {'name': comptitle, 'configurations': {}, 'confs_to_load': [confu]}
                     ncomps += 1
@@ -384,6 +382,7 @@ class _RMProject(_project._Project):
         return (ncomps, nconfs)
 
     def load_configs(self):
+        # load configurations
         while self._confs_to_load:
             confu = self._confs_to_load.pop()
             if not confu:
@@ -592,7 +591,6 @@ class _RMProject(_project._Project):
         return results
 
     def find_local_component(self, name_or_uri):
-        print( f"FLC {self=} {name_or_uri=}" )
         self.load_components_and_configurations()
         for compuri, compdetail in self._components.items():
             if compuri == name_or_uri or compdetail['name'] == name_or_uri:
