@@ -108,6 +108,7 @@ def do_oslc_query(inputargs=None):
     parser.add_argument('--saverawresults', default=None, help="Save the raw results as XML to this path/file prefix - pages are numbered starting from 0000" )
     parser.add_argument('--saveprocessedresults', default=None, help="Save the processed results as JSON to this path/file" )
     parser.add_argument('--percontribution', action="store_true", help="When querying a GC, query once for each app-domain contribution in the GC tree, with added component and configuration columns in the result")
+    parser.add_argument('--cacheable', action="store_true", help="Query results can be cached - use when you know the data isn't changing and you need faster re-run")
 
     # saved credentials
     parser.add_argument('-0', '--savecreds', default=None, help="Save obfuscated credentials file for use with readcreds, then exit - this stores jazzurl, appstring, username and password")
@@ -472,10 +473,13 @@ def do_oslc_query(inputargs=None):
         results = {}
         # get all the contributions in this domain, and the component they're in - these will be added to the results
         contribs = p.get_our_contributions(gcconfiguri)
-        for contriburi,compuri in contribs:
-            print( f"{contriburi=} {compuri=}" )
+        for i,(contriburi,compuri) in enumerate(contribs):
+            print( f"{i+1}/{len(contribs)} {contriburi=} {compuri=}" )
             # find the component in teh config
             queryon = p.find_local_component(compuri)
+            if queryon is None:
+                print( f"Component not found from {compuri}" )
+                continue
             queryon.set_local_config(contriburi)
             # now do a query for each contribution
             thisresults = queryon.do_complex_query( args.resourcetype, querystring=args.query, searchterms=args.searchterms, select=args.select, isnulls=args.null, isnotnulls=args.value
@@ -489,6 +493,7 @@ def do_oslc_query(inputargs=None):
                         ,totalize=args.totalize
                         ,saverawresults=args.saverawresults
                         ,addcolumns={'$contriburi':contriburi,'$compuri':compuri}
+                        ,cacheable=args.cacheable
                         )
             results.update(thisresults)
     else:    
@@ -503,6 +508,7 @@ def do_oslc_query(inputargs=None):
                         ,resolvenames = args.resolvenames
                         ,totalize=args.totalize
                         ,saverawresults=args.saverawresults
+                        ,cacheable=args.cacheable
                         )
 
     if args.debugprint:
@@ -575,10 +581,11 @@ def do_oslc_query(inputargs=None):
             # add the URI to the value so it will be exported (first char is $ so the uri will always be in first column after the column titles are sorted)
             v["$uri"] = k
             for sk in list(v.keys()):
+                # try to resolve heading names
                 sk1 = queryon.resolve_uri_to_name(sk) if args.resolvenames else sk
                 if sk not in rawheadings:
                     rawheadings.append(sk)
-                    if sk1 == sk: # if heading name hasn't been resolved before
+                    if args.resolvenames and sk1 == sk: # if heading name hasn't been resolved before
                         sk1 = queryon.resolve_uri_to_name(sk) # always resolve - only for headings
                     if sk1 not in headings:
                         headings.append(sk1)
